@@ -11,7 +11,7 @@ import textwrap
 import pytest
 
 from cryptography.hazmat.bindings._rust import openssl as rust_openssl
-from cryptography.hazmat.decrepit.ciphers.algorithms import RC2
+from cryptography.hazmat.decrepit.ciphers.algorithms import _DES, RC2
 from cryptography.hazmat.primitives.asymmetric import (
     dsa,
     ec,
@@ -22,7 +22,7 @@ from cryptography.hazmat.primitives.asymmetric import (
     x25519,
 )
 from cryptography.hazmat.primitives.ciphers import modes
-from cryptography.hazmat.primitives.hashes import SHA1
+from cryptography.hazmat.primitives.hashes import MD5, SHA1
 from cryptography.hazmat.primitives.serialization import (
     BestAvailableEncryption,
     Encoding,
@@ -463,6 +463,20 @@ class TestDERSerialization:
         with pytest.raises(ValueError):
             load_pem_private_key(data, password=b"password")
 
+    @pytest.mark.skip_fips(reason="3DES unsupported in FIPS")
+    def test_load_pkcs8_pbes_long_salt(self):
+        data = load_vectors_from_file(
+            os.path.join("asymmetric", "PKCS8", "rsa-pbe-3des-long-salt.pem"),
+            lambda f: f.read(),
+            mode="rb",
+        )
+        key = load_pem_private_key(
+            data, password=b"password", unsafe_skip_rsa_key_validation=True
+        )
+        assert isinstance(key, rsa.RSAPrivateKey)
+        assert key.key_size == 4096
+        assert key.private_numbers().public_numbers.e == 65537
+
     @pytest.mark.parametrize(
         "filename",
         [
@@ -559,6 +573,20 @@ class TestDERSerialization:
         )
         assert isinstance(key, ed25519.Ed25519PrivateKey)
 
+    @pytest.mark.supported(
+        only_if=lambda backend: backend.hash_supported(MD5())
+        and backend.cipher_supported(_DES(), modes.CBC(b"\x00" * 8)),
+        skip_message="Does not support DES MD5",
+    )
+    def test_load_pkcs8_pbe_with_md5_and_des_cbc(self):
+        key = load_vectors_from_file(
+            os.path.join("asymmetric", "PKCS8", "rsa-pbewithmd5anddescbc.pem"),
+            lambda f: load_pem_private_key(f.read(), password=b"hunter2"),
+            mode="rb",
+        )
+        assert isinstance(key, rsa.RSAPrivateKey)
+        assert key.key_size == 2048
+
 
 class TestPEMSerialization:
     @pytest.mark.parametrize(
